import { Link, NavLink, useLocation } from 'react-router'
import { Menu, Popover, Button } from 'antd'
import { CaretDownOutlined } from '@ant-design/icons'
import './AppHeader.scss'

export default function AppHeader({ title = 'AI数据分析实验室' }) {
  const location = useLocation()
  const defaultSelectedKeys = [location.pathname]

  const menus = [
    { name: '首页', path: '/' },
    { name: '我的实验', path: '/data' },
  ]

  const items = menus.map((item) => {
    return {
      label: <NavLink to={item.path}>{item.name}</NavLink>,
      key: item.path,
    }
  })

  return (
    <div className="app-header">
      <div className="app-header-left">
        <div className="logo">
          <Link to="/">
            <img src="https://webapp-pub.ezijing.com/website/base/logo.svg" />
          </Link>
        </div>
        <div className="line"></div>
        <h1 className="app-name">
          <Link to="/">{title}</Link>
        </h1>
      </div>
      <div className="app-header-nav">
        <Menu mode="horizontal" items={items} defaultSelectedKeys={defaultSelectedKeys} />
      </div>
      <div className="app-header-right">
        <Popover
          content={
            <div className="app-header-user">
              <div className="app-header-user-avatar">
                <img src="https://webapp-pub.ezijing.com/website/base/images/avatar.svg" />
              </div>
              <div className="app-header-user-main">
                <h3>王鹏飞</h3>
                <p>wangpengfei@ezijing.com</p>
              </div>
              <div className="app-header-user-buttons">
                <Button shape="round">退出登录</Button>
              </div>
            </div>
          }>
          <div className="user">
            <div className="avatar">
              <img src="https://webapp-pub.ezijing.com/website/base/images/avatar.svg" />
            </div>
            <p>王鹏飞</p>
            <CaretDownOutlined />
          </div>
        </Popover>
      </div>
    </div>
  )
}
